==> jm_basic_flutter-1.0.3.tar.gz: lib/widgets/picture_browser.dart <==
import 'dart:io';
import 'dart:math';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:photo_view/photo_view.dart';
import 'package:photo_view/photo_view_gallery.dart';

class PictureBrowser extends StatefulWidget {
  final int index;
  final List<PictureBrowserItem> images;

  const PictureBrowser({
    Key? key,
    this.index = 0,
    this.images = const [],
  }) : super(key: key);

  @override
  _PictureBrowser createState() => _PictureBrowser();
}

class _PictureBrowser extends State<PictureBrowser> {
  int _currentIndex = 0;

  @override
  void initState() {
    _currentIndex = widget.index;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        brightness: Brightness.dark,
        // 文字白色
        backgroundColor: Colors.black,
        centerTitle: true,
        leading: BackButton(
          color: Colors.white,
        ),
        title: Text(
          "${_currentIndex + 1}/${widget.images.length}",
          style: TextStyle(color: Colors.white, fontSize: 16, fontWeight: FontWeight.bold),
        ),
      ),
      body: Container(
        color: Colors.black,
        child: Column(
          children: [
            Expanded(
              child: Stack(
                children: [
                  Container(
                    color: Colors.black,
                    padding: EdgeInsets.only(bottom: MediaQuery.of(context).padding.bottom + 24),
                    child: PhotoViewGallery.builder(
                      scrollPhysics: const BouncingScrollPhysics(),
                      builder: (BuildContext context, int index) {
                        PictureBrowserItem image = widget.images[index];
                        return PhotoViewGalleryPageOptions(
                          initialScale: PhotoViewComputedScale.contained * 0.99,
                          imageProvider: _imageProvider(image),
                        );
                      },
                      loadingBuilder: (context, event) {
                        double value = (event == null || event.expectedTotalBytes == 0) ? 0 : event.cumulativeBytesLoaded / event.expectedTotalBytes!;
                        value = max(0.05, value);
                        return Center(
                          child: Container(
                            width: 40,
                            height: 40,
                            child: CircularProgressIndicator(
                              value: value,
                            ),
                          ),
                        );
                      },
                      itemCount: widget.images.length,
                      pageController: PageController(initialPage: _currentIndex),
                      enableRotation: true,
                      onPageChanged: (index) {
                        setState(() {
                          _currentIndex = index;
                        });
                      },
                    ),
                  ),
                  Positioned(
                    left: 0,
                    right: 0,
                    bottom: 0,
                    child: _remarkText(),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }

  ImageProvider _imageProvider(PictureBrowserItem image) {
    if (image.localImagePath == null || image.localImagePath.isEmpty) {
      return CachedNetworkImageProvider(image.imageUrl, headers: {'Accept': '*/*'});
    }
    return Image.file(File(image.localImagePath)).image;
  }

  Widget _remarkText() {
    var image = widget.images[_currentIndex];
    if (image.remark.length == 0) {
      return Container(width: 0, height: 0);
    } else {
      return Container(
        width: double.infinity,
        padding: EdgeInsets.fromLTRB(12, 8, 12, MediaQuery.of(context).padding.bottom + 8),
        decoration: BoxDecoration(color: Color(0x66333333)),
        child: Text(image.remark, style: TextStyle(color: Colors.white, fontSize: 13, fontWeight: FontWeight.normal)),
      );
    }
  }
}

class PictureBrowserItem {
  String imageUrl; // 图片 http url
  String localImagePath; // 本地 url
  String remark; // remark

  PictureBrowserItem({
    this.imageUrl = '',
    this.localImagePath = '',
    this.remark = '',
  });
}

==> jm_basic_flutter-1.0.4.tar.gz: lib/widgets/picture_browser.dart <==
import 'dart:io';
import 'dart:math';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:photo_view/photo_view.dart';
import 'package:photo_view/photo_view_gallery.dart';

class PictureBrowser extends StatefulWidget {
  final int index;
  final List<PictureBrowserItem> images;

  const PictureBrowser({
    Key? key,
    this.index = 0,
    this.images = const [],
  }) : super(key: key);

  @override
  _PictureBrowser createState() => _PictureBrowser();
}

class _PictureBrowser extends State<PictureBrowser> {
  int _currentIndex = 0;

  @override
  void initState() {
    _currentIndex = widget.index;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        systemOverlayStyle: SystemUiOverlayStyle(
          statusBarBrightness: Brightness.dark,
          statusBarIconBrightness: Brightness.dark,
          systemNavigationBarIconBrightness: Brightness.dark,
        ),
        // 文字白色
        backgroundColor: Colors.black,
        centerTitle: true,
        leading: BackButton(
          color: Colors.white,
        ),
        title: Text(
          "${_currentIndex + 1}/${widget.images.length}",
          style: TextStyle(color: Colors.white, fontSize: 16, fontWeight: FontWeight.bold),
        ),
      ),
      body: Container(
        color: Colors.black,
        child: Column(
          children: [
            Expanded(
              child: Stack(
                children: [
                  Container(
                    color: Colors.black,
                    padding: EdgeInsets.only(bottom: MediaQuery.of(context).padding.bottom + 24),
                    child: PhotoViewGallery.builder(
                      scrollPhysics: const BouncingScrollPhysics(),
                      builder: (BuildContext context, int index) {
                        PictureBrowserItem image = widget.images[index];
                        return PhotoViewGalleryPageOptions(
                          initialScale: PhotoViewComputedScale.contained * 0.99,
                          imageProvider: _imageProvider(image),
                        );
                      },
                      loadingBuilder: (context, event) {
                        double value = (event == null || event.expectedTotalBytes == 0) ? 0 : event.cumulativeBytesLoaded / event.expectedTotalBytes!;
                        value = max(0.05, value);
                        return Center(
                          child: Container(
                            width: 40,
                            height: 40,
                            child: CircularProgressIndicator(
                              value: value,
                            ),
                          ),
                        );
                      },
                      itemCount: widget.images.length,
                      pageController: PageController(initialPage: _currentIndex),
                      enableRotation: true,
                      onPageChanged: (index) {
                        setState(() {
                          _currentIndex = index;
                        });
                      },
                    ),
                  ),
                  Positioned(
                    left: 0,
                    right: 0,
                    bottom: 0,
                    child: _remarkText(),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }

  ImageProvider _imageProvider(PictureBrowserItem image) {
    if (image.localImagePath.isEmpty) {
      return CachedNetworkImageProvider(image.imageUrl, headers: {'Accept': '*/*'});
    }
    return Image.file(File(image.localImagePath)).image;
  }

  Widget _remarkText() {
    var image = widget.images[_currentIndex];
    if (image.remark.length == 0) {
      return Container(width: 0, height: 0);
    } else {
      return Container(
        width: double.infinity,
        padding: EdgeInsets.fromLTRB(12, 8, 12, MediaQuery.of(context).padding.bottom + 8),
        decoration: BoxDecoration(color: Color(0x66333333)),
        child: Text(image.remark, style: TextStyle(color: Colors.white, fontSize: 13, fontWeight: FontWeight.normal)),
      );
    }
  }
}

class PictureBrowserItem {
  String imageUrl; // 图片 http url
  String localImagePath; // 本地 url
  String remark; // remark

  PictureBrowserItem({
    this.imageUrl = '',
    this.localImagePath = '',
    this.remark = '',
  });
}
